# Using GEOS as library
## Reading mapsources

```eval_rst
.. automodule:: geos.mapsource
    :members:
    :undoc-members:
```

## Printing maps

```eval_rst
.. automodule:: geos.print
    :members:
    :undoc-members:
```

## Geometry

```eval_rst
.. automodule:: geos.geometry
    :members:
    :undoc-members:
```
